@@ -3,6 +3,7 @@ import dill
 import numpy as np
 import pandas as pd
 import torch
+import io
 import torch.optim as optim
 from torch import nn, FloatTensor
 from torchtext import data
@@ -161,8 +162,12 @@ class TorchTagger:
 
     def save(self, path):
         """Saves model on disk."""
+
+        buffer = io.BytesIO()
+        torch.save(self.model, buffer)
+
         to_save = {
-            "torch_tagger": self.model,
+            "torch_tagger": buffer,
             "text_field": self.text_field,
             "label_reverse_index": self.label_reverse_index
         }
@@ -174,7 +179,10 @@ class TorchTagger:
     def load(self, path):
         """Loads model from disk."""
         with open(path, 'rb') as file:
-            loaded = dill.load(file)
+            try:
+                loaded = dill.load(file)
+            except RuntimeError:
+                raise exceptions.IncompatibleVersionAndDeviceError(f'The models trained on texta-torch-tagger version <=1.1.1 cannot be loaded onto current device if they were trained on another type of device.')
         # set class variables
         self._set_loaded_values(loaded)
         self.text_processor.phraser = self.embedding.phraser
@@ -197,13 +205,29 @@ class TorchTagger:
             * text_field,
             * label_reverse_index.
         """
-        # eval model
-        loaded["torch_tagger"].eval()
+        if isinstance(loaded["torch_tagger"], io.BytesIO):
+            buffer = loaded["torch_tagger"]
+            buffer.seek(0)
+
+            # Get current device
+            if torch.cuda.is_available():
+                device = torch.device("cuda")
+            else:
+                device = torch.device("cpu")
+
+            self.model = torch.load(buffer, map_location=device)
+
+        # Make it compatible with older models
+        else:
+            self.model = loaded["torch_tagger"]
+
         # set values
-        self.model = loaded["torch_tagger"]
         self.text_field = loaded["text_field"]
         self.label_reverse_index = loaded["label_reverse_index"]
 
+        # eval model
+        self.model.eval()
+
 
     def _get_examples_and_labels(self, data_sample):
         # lists for examples and labels
